@@ -8,12 +8,6 @@ from traits.api \
            Property, Str, Trait
 from kiva.constants import FILL, STROKE
 
-try:
-    from kiva.gl import GraphicsContext as GraphicsContextGL
-except (ImportError, TypeError):
-    class GraphicsContextGL(object):
-        pass
-
 # Local relative imports
 from colors import black_color_trait, white_color_trait
 from coordinate_box import CoordinateBox
@@ -513,6 +507,24 @@ class Component(CoordinateBox, Interactor):
         else:
             offset_x, offset_y = self.position
         return (offset_x + coords[0], offset_y + coords[1])
+ 
+    def get_relative_coords(self, *coords):
+        """ Given absolute coordinates (where the origin is the top-left corner
+        of the frame in the top-level parent Window) return coordinates relative
+        to this component's origin.
+
+        Can be called in two ways:
+            get_relative_coords(x, y)
+            get_relative_coords( (x,y) )
+
+        Returns a tuple (x,y) representing the new coordinates.
+        """
+        if self.container is not None:
+            offset_x, offset_y = \
+                    self.container.get_relative_coords(*self.position)
+        else:
+            offset_x, offset_y = self.position
+        return (coords[0] - offset_x, coords[1] - offset_y)
 
     def request_redraw(self):
         """
@@ -705,7 +717,11 @@ class Component(CoordinateBox, Interactor):
         self.drawn_outer_position = list(self.outer_position[:])
         self.drawn_outer_bounds = list(self.outer_bounds[:])
 
-        if self.use_backbuffer and (not isinstance(gc, GraphicsContextGL)):
+        # OpenGL-based graphics-contexts have a `gl_init()` method. We
+        # test for this to avoid having to import the OpenGL
+        # GraphicsContext just to do an isinstance() check.
+        is_gl = hasattr(gc, 'gl_init')
+        if self.use_backbuffer and (not is_gl):
             if self.backbuffer_padding:
                 x, y = self.outer_position
                 width, height = self.outer_bounds
@@ -1203,7 +1219,6 @@ class Component(CoordinateBox, Interactor):
     #------------------------------------------------------------------------
 
     def _get_outer_bounds(self):
-        border = self._get_visible_border()
         bounds = self.bounds
         return (bounds[0] + self.hpadding, bounds[1] + self.vpadding)
 
