@@ -14,6 +14,7 @@
 # been on my list of things to do.
 #------------------------------------------------------------------------------
 
+
 # Qt imports.
 from pyface.qt import QtCore, QtGui, QtOpenGL
 
@@ -32,6 +33,8 @@ class _QtWindowHandler(object):
         pos = qt_window.mapFromGlobal(QtGui.QCursor.pos())
         self.last_mouse_pos = (pos.x(), pos.y())
 
+        self.in_paint_event = False
+
         qt_window.setAutoFillBackground(True)
         qt_window.setFocusPolicy(QtCore.Qt.WheelFocus)
         qt_window.setMouseTracking(True)
@@ -43,7 +46,9 @@ class _QtWindowHandler(object):
         self._enable_window = None
 
     def paintEvent(self, event):
+        self.in_paint_event = True
         self._enable_window._paint(event)
+        self.in_paint_event = False
 
     def resizeEvent(self, event):
         dx = event.size().width()
@@ -112,6 +117,41 @@ class _QtWindowHandler(object):
         if self._enable_window:
             self._enable_window._handle_mouse_event("mouse_wheel", event)
 
+    def sizeHint(self, qt_size_hint):
+        """ Combine the Qt and enable size hints.
+
+        Combine the size hint coming from the Qt component (usually -1, -1)
+        with the preferred size of the enable component and the size
+        of the enable window.
+
+        The combined size hint is
+        - the Qt size hint if larger than 0
+        - the maximum of the plot's preferred size and the window size
+          (component-wise)
+
+        E.g., if
+        qt size hint = (-1, -1)
+        component preferred size = (500, 200)
+        size of enable window = (400, 400)
+
+        the final size hint will be (500, 400)
+        """
+
+        preferred_size = self._enable_window.component.get_preferred_size()
+        q_size = self._enable_window.control.size()
+        window_size = (q_size.width(), q_size.height())
+
+        if qt_size_hint.width() < 0:
+            width = max(preferred_size[0], window_size[0])
+            qt_size_hint.setWidth(width)
+
+        if qt_size_hint.height() < 0:
+            height = max(preferred_size[1], window_size[1])
+            qt_size_hint.setHeight(height)
+
+        return qt_size_hint
+
+
     #------------------------------------------------------------------------
     # Qt Drag and drop event handlers
     #------------------------------------------------------------------------
@@ -131,6 +171,7 @@ class _QtWindowHandler(object):
 
 class _QtWindow(QtGui.QWidget):
     """ The Qt widget that implements the enable control. """
+
     def __init__(self, parent, enable_window):
         super(_QtWindow, self).__init__(parent)
         self.handler = _QtWindowHandler(self, enable_window)
@@ -184,6 +225,10 @@ class _QtWindow(QtGui.QWidget):
     def dropEvent(self, event):
         self.handler.dropEvent(event)
 
+    def sizeHint(self):
+        qt_size_hint = super(_QtWindow, self).sizeHint()
+        return self.handler.sizeHint(qt_size_hint)
+
 
 class _QtGLWindow(QtOpenGL.QGLWidget):
     def __init__(self, parent, enable_window):
@@ -241,6 +286,11 @@ class _QtGLWindow(QtOpenGL.QGLWidget):
     def dropEvent(self, event):
         self.handler.dropEvent(event)
 
+    # TODO: by symmetry this belongs here, but we need to test it
+    #def sizeHint(self):
+    #    qt_size_hint = super(_QtGLWindow, self).sizeHint()
+    #    return self.handler.sizeHint(qt_size_hint)
+
 
 class _Window(AbstractWindow):
 
@@ -316,6 +366,9 @@ class _Window(AbstractWindow):
                         window=self)
 
     def _create_mouse_event(self, event):
+        # If the control no longer exists, don't send mouse event
+        if self.control is None:
+            return None
         # If the event (if there is one) doesn't contain the mouse position,
         # modifiers and buttons then get sensible defaults.
         try:
@@ -352,6 +405,10 @@ class _Window(AbstractWindow):
 
     def _redraw(self, coordinates=None):
         if self.control:
+            if self.control.handler.in_paint_event:
+                # Code further up the stack is behaving badly and calling
+                # request_redraw() inside drawing code.
+                return
             if coordinates is None:
                 self.control.update()
             else:
@@ -384,6 +441,12 @@ class _Window(AbstractWindow):
 
     def _on_key_pressed(self, event):
         return self._handle_key_event('key_pressed', event)
+    
+    def get_pointer_position(self):
+        pos = self.control.mapFromGlobal(QtGui.QCursor.pos())
+        x = pos.x()
+        y = self._flip_y(pos.y())
+        return x, y
             
 
     #------------------------------------------------------------------------
