@@ -1,9 +1,6 @@
 """
 Demonstrates how clipping of objects occurs with the view_bounds parameter to draw().
 """
-
-from __future__ import with_statement
-
 from enable.example_support import DemoFrame, demo_main
 
 from enable.api import Container, Component, Scrolled, Window
@@ -20,6 +17,7 @@ class Box(Component):
             gc.fill_path()
         return
 
+
 class VerboseContainer(Container):
     """
     By default a container just doesn't draw contained components if they are
@@ -76,7 +74,7 @@ class MyFrame(DemoFrame):
 
 
 if __name__ == "__main__":
-    demo_main(MyFrame, title="Use the scroll bars to show and hide components")
-
-
-# EOF
+    title = "Use the scroll bars to show and hide components"
+    # Save demo so that it doesn't get garbage collected when run within
+    # existing event loop (i.e. from ipython).
+    demo = demo_main(MyFrame, title=title)
